#!/usr/bin/perl

#Include current script directory in the module path (needed on Microsoft IIS).
#This allows this script to work by copying ChartDirector to the same directory
#as the script (as an alternative to installation in Perl module directory)
use File::Basename;
use lib dirname($0);

use perlchartdir;

#standard code to parse HTTP query parameters
%query = map {my($k,$v) = split(/=/)} split(/&/, $ENV{"QUERY_STRING"});

#Get the selected year.
my $selectedYear = $query{"xLabel"};

#Get the total revenue
my $totalRevenue = $query{"value"};

#
#  In this demo, we just split the total revenue into 12 months using random
#  numbers. In real life, the data can come from a database.
#
srand($selectedYear);
my @temp = (0) x 12;
my $data = \@temp;
for($i = 0; $i < 11; ++$i) {
    $data->[$i] = $totalRevenue * (rand() * 0.6 + 0.6) / (12 - $i);
    $totalRevenue = $totalRevenue - $data->[$i];
}
$data->[11] = $totalRevenue;

#
#  Now we obtain the data into arrays, we can start to draw the chart using
#  ChartDirector
#

#Create a XYChart object of size 450 x 200 pixels
my $c = new XYChart(450, 200);

#Add a title to the chart
$c->addTitle("Month Revenue for Star Tech for $selectedYear", "timesbi.ttf");

#Set the plotarea at (60, 5) and of size 350 x 150 pixels. Enable both
#horizontal and vertical grids by setting their colors to grey (0xc0c0c0)
$c->setPlotArea(60, 25, 350, 150)->setGridColor(0xc0c0c0, 0xc0c0c0);

#Add a line chart layer using the data
my $dataSet = $c->addLineLayer()->addDataSet($data, 0x993399);

#Set the line width to 3 pixels
$dataSet->setLineWidth(3);

#Use a 11 point triangle symbol to plot the data points
$dataSet->setDataSymbol($perlchartdir::TriangleSymbol, 11);

#Set the x axis labels. In this example, the labels must be Jan - Dec.
my $labels = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sept",
    "Oct", "Nov", "Dec"];
$c->xAxis()->setLabels($labels);

#Add a title to the x axis to reflect the selected year
$c->xAxis()->setTitle("Year $selectedYear");

#Add a title to the y axis
$c->yAxis()->setTitle("USD (K)");

#Reserve 10% margin at the top of the plot area just to make sure the line does
#not go too near the top of the plot area
$c->yAxis()->setAutoScale(0.1);

#Create the image and save it in a temporary location
my $chart1URL = $c->makeTmpFile("/tmp/tmpcharts");

#Create an image map for the chart
my $imageMap = $c->getHTMLImageMap("clickpie.pl?year=$selectedYear", "",
    "title='{xLabel}: USD {value|0}K'");

print "Content-type: text/html\n\n";
print <<EndOfHTML
<html>
<body>
<h1>Simple Clickable Line Chart</h1>
<p><a href="viewsource.pl?file=$ENV{"SCRIPT_NAME"}">
View Source Code
</a></p>

<img src="myimage.pl?img=/tmp/tmpcharts/$chart1URL" border="0" usemap="#map1">
<map name="map1">
$imageMap
</map>
</body>
</html>
EndOfHTML
;
