#!/usr/bin/perl

#Include current script directory in the module path (needed on Microsoft IIS).
#This allows this script to work by copying ChartDirector to the same directory
#as the script (as an alternative to installation in Perl module directory)
use File::Basename;
use lib dirname($0);

use perlchartdir;

#standard code to parse HTTP query parameters
%query = map {my($k,$v) = split(/=/)} split(/&/, $ENV{"QUERY_STRING"});

#Get the selected year and month
my $selectedYear = $query{"year"};
my $selectedMonth = $query{"x"} + 1;

#Get the monthly revenue
my $monthlyRevenue = $query{"value"};

#
#  In this demo, we just split the total revenue into 3 parts using random
#  numbers. In real life, the data probably can come from a database.
#
srand($selectedMonth * 2000 + $selectedYear);
my @temp = (0) x 3;
my $data = \@temp;
$data->[0] = (rand() * 0.1 + 0.5) * $monthlyRevenue;
$data->[1] = (rand() * 0.1 + 0.2) * $monthlyRevenue;
$data->[2] = $monthlyRevenue - $data->[0] - $data->[1];

#The labels for the pie chart
my $labels = ["Services", "Hardware", "Software"];

#Create a PieChart object of size 360 x 260 pixels
my $c = new PieChart(360, 260);

#Set the center of the pie at (180, 140) and the radius to 100 pixels
$c->setPieSize(180, 130, 100);

#Add a title to the pie chart using 13 pts Times Bold Italic font
$c->addTitle("Revenue Breakdown for $selectedMonth/$selectedYear",
    "timesbi.ttf", 13);

#Draw the pie in 3D
$c->set3D();

#Set the pie data and the pie labels
$c->setData($data, $labels);

#Create the image and save it in a temporary location
my $chart1URL = $c->makeTmpFile("/tmp/tmpcharts");

#Create an image map for the chart
my $imageMap = $c->getHTMLImageMap("piestub.pl", "",
    "title='{label}:USD {value|0}K'");

print "Content-type: text/html\n\n";
print <<EndOfHTML
<html>
<body>
<h1>Simple Clickable Pie Chart</h1>
<p><a href="viewsource.pl?file=$ENV{"SCRIPT_NAME"}">
View Source Code
</a></p>

<img src="myimage.pl?img=/tmp/tmpcharts/$chart1URL" border="0" usemap="#map1">
<map name="map1">
$imageMap
</map>
</body>
</html>
EndOfHTML
;
