#!/usr/bin/perl

#Include current script directory in the module path (needed on Microsoft IIS).
#This allows this script to work by copying ChartDirector to the same directory
#as the script (as an alternative to installation in Perl module directory)
use File::Basename;
use lib dirname($0);

use perlchartdir;
use DBI;

#standard code to parse HTTP query parameters
my %query = map {my($k,$v) = split(/=/)} split(/&/, $ENV{"QUERY_STRING"});

#
#Displays the monthly revenue for the selected year. The selected year
#should be passed in as a query parameter called "year"
#
my $selectedYear = ($query{"year"} or 2001);

#
#Create an SQL statement to get the revenues of each month for the
#selected year.
#
my $SQLstatement = "Select Month(TimeStamp) - 1, " .
      "Software, Hardware, Services " .
      "From revenue Where Year(TimeStamp)=$selectedYear";

#
#Read in the revenue data into arrays
#
my $dbh = DBI->connect('dbi:mysql:sample','test','test');
my $sth = $dbh->prepare($SQLstatement);

my @software = (0) x 12;
my @hardware = (0) x 12;
my @services = (0) x 12;
$sth->execute();
while (my @row = $sth->fetchrow_array) {
	$software[$row[0]] = $row[1];
	$hardware[$row[0]] = $row[2];
	$services[$row[0]] = $row[3];
}
$dbh->disconnect;

#
#Now we obtain the data into arrays, we can start to draw the chart 
#using ChartDirector
#	
	
#Create a XYChart of size 420 pixels x 240 pixels
my $c = new XYChart(420, 240);

#Set the chart background to pale yellow (0xffffc0) with a 2 pixel 3D border
$c->setBackground(0xffffc0, 0xffffc0, 2);
	
#Set the plotarea at (70, 50) and of size 320 x 150 pixels. Set background
#color to white (0xffffff). Enable both horizontal and vertical grids by
#setting their colors to light grey (0xc0c0c0)
$c->setPlotArea(70, 50, 320, 150, 0xffffff, 0xffffff, 0xc0c0c0, 0xc0c0c0);

#Add a title to the chart
$c->addTitle("Revenue for $selectedYear", "timesbi.ttf")
	->setBackground(0xffff00);

#Add a legend box at the top of the plotarea
$c->addLegend(70, 30, 0, "", 8)->setBackground($perlchartdir::Transparent);

#Add a stacked bar chart layer using the supplied data
my $layer = $c->addBarLayer2($perlchartdir::Stack);
$layer->addDataSet(\@software, -1, "Software");
$layer->addDataSet(\@hardware, -1, "Hardware");
$layer->addDataSet(\@services, -1, "Services");
$layer->setBorderColor($perlchartdir::Transparent, 1);
	
#Set the x axis labels. In this example, the labels must be Jan - Dec.
my @labels = ("Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug",
	"Sept", "Oct", "Nov", "Dec");
$c->xAxis->setLabels(\@labels);

#Set the x-axis width to 2 pixels
$c->xAxis->setWidth(2);

#Set the y axis title
$c->yAxis->setTitle("USD (K)");

#Set the y-axis width to 2 pixels
$c->yAxis->setWidth(2);

#Output the chart
binmode(STDOUT);
print "Content-type: image/png\n\n";
print $c->makeChart2($perlchartdir::PNG);
